from pathlib import Path
from typing import FrozenSet, List, Optional

from pyswot.vendor.domains import DOMAINS
from pyswot.vendor.stoplist import STOPLIST
from pyswot.vendor.tlds import TLDS


def _read_list(rel_path: str):
    with open(Path(__file__).parent / rel_path) as f:
        stoplist = frozenset(f.read().splitlines())
    return stoplist


def is_academic(email: str) -> bool:
    parts = _domain_parts(email)
    return not _is_stoplisted(parts) and (
        _is_under_tld(parts) or bool(_find_school_names(parts))
    )


def find_school_names(email: str) -> List[Optional[str]]:
    return _find_school_names(_domain_parts(email))


def _is_under_tld(parts: List[str]) -> bool:
    return _check_set(TLDS, parts)


def _is_stoplisted(parts: List[str]) -> bool:
    return _check_set(STOPLIST, parts)


def _find_school_names(parts: List[str]) -> List[Optional[str]]:
    key = ""
    for part in parts:
        key = f".{part}{key}"
        try:
            return DOMAINS[key]
        except KeyError:
            continue

    return []


def _domain_parts(email_or_domain: str) -> List[str]:
    email_or_domain = email_or_domain.strip().lower()

    parts = email_or_domain.split("@")[-1].split(".")
    parts.reverse()

    return parts


def _check_set(s: FrozenSet[str], parts: List[str]) -> bool:
    t = ""
    for part in parts:
        t = f"{part}{t}"
        if t in s:
            return True
        t = f".{t}"
    return False



# Updated 2022-02-15T12:23:42.311577 from git@github.com:JetBrains/swot.git@38c46e53

TLDS = frozenset(
    [
        "ac.bd",
        "ac.be",
        "ac.cr",
        "ac.cy",
        "ac.gg",
        "ac.gn",
        "ac.il",
        "ac.in",
        "ac.jp",
        "ac.ke",
        "ac.kr",
        "ac.ma",
        "ac.me",
        "ac.mw",
        "ac.mz",
        "ac.ni",
        "ac.om",
        "ac.pa",
        "ac.pg",
        "ac.pr",
        "ac.ru",
        "ac.rw",
        "ac.sz",
        "ac.uk",
        "ac.yu",
        "ac.za",
        "ac.zm",
        "ac.zw",
        "ed.ao",
        "ed.cr",
        "ed.jp",
        "edu",
        "edu.al",
        "edu.ar",
        "edu.az",
        "edu.ba",
        "edu.bb",
        "edu.bd",
        "edu.bh",
        "edu.bn",
        "edu.bs",
        "edu.bz",
        "edu.ck",
        "edu.cn",
        "edu.dz",
        "edu.ee",
        "edu.er",
        "edu.et",
        "edu.gh",
        "edu.gt",
        "edu.hn",
        "edu.in",
        "edu.jm",
        "edu.jo",
        "edu.kh",
        "edu.kn",
        "edu.kw",
        "edu.kz",
        "edu.lr",
        "edu.ly",
        "edu.me",
        "edu.mg",
        "edu.ml",
        "edu.mn",
        "edu.mo",
        "edu.mt",
        "edu.mv",
        "edu.mw",
        "edu.mx",
        "edu.ni",
        "edu.np",
        "edu.pa",
        "edu.pe",
        "edu.ph",
        "edu.pk",
        "edu.pr",
        "edu.pt",
        "edu.pw",
        "edu.py",
        "edu.qa",
        "edu.ru",
        "edu.sa",
        "edu.sc",
        "edu.sd",
        "edu.sh",
        "edu.sl",
        "edu.sv",
        "edu.sy",
        "edu.tt",
        "edu.ve",
        "edu.ws",
        "edu.ye",
        "edu.zm",
        "es.kr",
        "g12.br",
        "hs.kr",
        "ms.kr",
        "sc.kr",
        "sch.ae",
        "sch.gg",
        "sch.id",
        "sch.je",
        "sch.jo",
        "sch.lk",
        "sch.ly",
        "sch.my",
        "sch.om",
        "sch.ps",
        "sch.sa",
        "sch.uk",
        "school.za",
        "urfu.me",
        "vic.edu.au",
    ]
)



# Updated 2022-02-15T12:23:42.311097 from git@github.com:JetBrains/swot.git@38c46e53

STOPLIST = frozenset(
    [
        "2020.gsm.cocite.pt",
        "90888.cc",
        "aaedu.edu.pl",
        "abcda.tech",
        "ahlg.ac.cn",
        "ahzyygz.edu.cn",
        "al.insper.edu.br",
        "alu.comillas.edu",
        "alu.fudan.edu.cn",
        "alum.ccu.edu.tw",
        "alum.urmc.rochester.edu",
        "alumni.albany.edu",
        "alumni.cmu.edu",
        "alumni.edu.vn",
        "alumni.montclair.edu",
        "alumni.nottingham.ac.uk",
        "alumni.sjtu.edu.cn",
        "alumni.unc.edu",
        "alumni.usp.br",
        "alumni.vcu.edu",
        "america.edu",
        "anadolu.edu.tr",
        "app",
        "apus.edu",
        "art.edu.lv",
        "asu.edu",
        "aufe.edu.cn",
        "aurora.ekof.bg.ac.rs",
        "australia.edu",
        "ayit.edu.cn",
        "azwestern.edu",
        "bbc.edu.cn",
        "bcmail.cuny.edu",
        "bese.ac.cn",
        "bestlistbase.com",
        "bfsu.edu.cn",
        "bgu.edu.kg",
        "bit.edu.cn",
        "bitzh.edu.cn",
        "bjdx.ac.cn",
        "bjlg.ac.cn",
        "bjtu.edu.cn",
        "bnu.edu.cn",
        "boscuos.com",
        "bucea.edu.cn",
        "caa.columbia.edu",
        "caa.edu.cn",
        "californiacolleges.edu",
        "campus.mccd.edu",
        "cau.edu.cn",
        "cc.peralta.edu",
        "ccc.edu",
        "cccd.edu",
        "ccnu.edu.cn",
        "ccsf.edu",
        "ccu.edu.tw",
        "cczu.edu.cn",
        "cdmc.edu.cn",
        "cet.edu",
        "cf",
        "chasefreedomactivate.com",
        "chc.edu.tw",
        "chd.edu.cn",
        "cheoa.studio",
        "cihanuniversity.org",
        "cjlu.edu.cn",
        "clatsopcc.edu",
        "cloudlearn.tech",
        "cmail.cornell.edu",
        "cochise.edu",
        "cocite.pt",
        "codesra.cn",
        "colegiotorremalmuerta.es",
        "collin.edu",
        "connect.hku.hk",
        "correo.icesi.edu.co",
        "cougarmail.collin.edu",
        "cpcc.edu",
        "cqu.edu.cn",
        "csu.ph",
        "ctgu.edu.cn",
        "cug.edu.cn",
        "cumt.edu.cn",
        "cumtb.edu.cn",
        "cuu.ac.ug",
        "davidsonccc.edu",
        "dcic.me",
        "deltacollege.edu",
        "dhu.edu.cn",
        "dlut.edu.cn",
        "dnmd.fun",
        "dragons.hutchcc.edu",
        "dxss.ac.cn",
        "dzxy.ntu.edu.cn",
        "eafit.edu.co",
        "eastafricauniversity.net",
        "ecupl.edu.cn",
        "ecust.edu.cn",
        "edu.icoremail.net",
        "edu.moi",
        "edu.tanta.edu.eg",
        "edu.uca.ma",
        "edu.umi.ac.ma",
        "educn.ac.cn",
        "email",
        "email.axc.edu.gr",
        "email.t.edu.vn",
        "emlmuak.cn",
        "enayu.com",
        "esore.asia",
        "esprims.tn",
        "eufe.edu.ht",
        "eurasia.edu",
        "everettcc.edu",
        "fjys.edu.cn",
        "fountaingatesc.vic.edu.au",
        "freenet.kg",
        "freenet.kg",
        "ga",
        "gduf.edu.cn",
        "ghazanthemprep.org",
        "giant.cos.edu",
        "go.edu.tw",
        "go.minnstate.edu",
        "go.sfcollege.edu",
        "gq",
        "graduate.hku.hk",
        "gsm.cocite.pt",
        "gsuite.cornell.edu",
        "gydx.ac.cn",
        "gzhtcm.edu.cn",
        "gzhu.edu.cn",
        "hainanu.edu.cn",
        "hainu.edu.cn",
        "haust.edu.cn",
        "haywood.edu",
        "hbdx.ac.cn",
        "hbu.edu.cn",
        "hbut.edu.cn ",
        "hc.edu.tw",
        "hcc.edu.tw",
        "hcmup.edu.vn",
        "henu.edu.cn",
        "hhu.edu.cn",
        "hiast.edu.vn",
        "hndx.ac.cn",
        "hnit.ed.cn",
        "hnu.edu.cn",
        "hqu.edu.cn",
        "hrbeu.edu.cn",
        "hstu.info",
        "huanghuai.edu.cn",
        "hubu.edu.cn",
        "hufe.edu.cn",
        "huse.edu.cn",
        "hust.edu.cn",
        "hznu.edu.cn",
        "icamtech.com",
        "iga-marrakech.ma",
        "imghost.tech",
        "imnu.edu.cn",
        "insite.4cd.edu",
        "int.edu.gr",
        "ipdbuu.com.cn",
        "ishikuniversity.net",
        "itu.ac.tzbjtu.edu.cn",
        "jiangnan.edu.cn",
        "jlu.edu.cn",
        "jmu.edu.cn",
        "jou.edu.cn",
        "jsust.edu.cn",
        "jsut.edu.cn",
        "k.kkk.ac.nz",
        "k.tut.edu.pl",
        "kashop.me",
        "kbtut.tj",
        "kg.edu.kg",
        "khi.iba.edu.pk",
        "kings.ac.id",
        "kings.edu.uy",
        "kjdx.ac.cn",
        "kkk.ac.nz",
        "kkk.school.nz",
        "kmismail.com",
        "kmust.edu.cn",
        "kst.edu.sg",
        "kust.edu.cn",
        "kyile.website",
        "leonvero.com",
        "lfnu.edu.cn",
        "live",
        "lixin.edu.cn",
        "ljb.edu.hk",
        "losrios.edu",
        "lucbjtu.ac.uk",
        "lxiv.secondary.edu.pl",
        "lzjtu.edu.cn",
        "lzpcc.edu.cn",
        "lzu.edu.cn",
        "m.fafu.edu.cn",
        "m.uno.edu.gr",
        "madisoncollege.edu",
        "mail.0du.win",
        "mail.ac.id",
        "mail.alumni.edu.vn",
        "mail.broward.edu",
        "mail.csu.edu.cn",
        "mail.davistech.edu",
        "mail.dhu.edu.cn",
        "mail.dream.edu.kg",
        "mail.edu.tw",
        "mail.fmftsk.cn",
        "mail.hbut.edu.cn",
        "mail.hrka.net",
        "mail.irsc.edu",
        "mail.ltcc.edu",
        "mail.mss.sc.ug",
        "mail.mzr.me",
        "mail.ntust.edu.tw",
        "mail.nwpu.edu.cn",
        "mail.philau.edu",
        "mail.sbu.ac.ir",
        "mail.sjtu.edu.cn",
        "mail.sustc.edu.cn",
        "mail.uic.edu.cn",
        "mail.wcccd.edu",
        "mail.xjtu.edu.cn",
        "mail2.gdut.edu.cn",
        "mailpoof.com",
        "mails.cust.edu.cn",
        "mails.hufe.edu.cn",
        "mails.imnu.edu.cn",
        "mails.mmnnsf.cn",
        "mails.qust.edu.cn",
        "mails.tsinghua.edu.cn",
        "masu.edu.cn",
        "mccd.edu",
        "mclennan.edu",
        "mdu.edu.rs",
        "me.bergen.edu",
        "mechnik.spb.ru",
        "mgccc.edu",
        "mgt.sjp.ac.lk",
        "mhzayt.online",
        "miitt.space",
        "miucce.com",
        "mjj.edu.ge",
        "ml",
        "ms.edu.tw",
        "msjc.edu",
        "my.anokaramsey.edu",
        "my.browncollege.edu",
        "my.canyons.edu",
        "my.ccri.edu",
        "my.chattanoogastate.edu",
        "my.cleveland.edu",
        "my.edu.moi",
        "my.jcu.edu.au",
        "my.riohondo.edu",
        "my.smccd.edu",
        "my.tccd.edu",
        "my.unitec.edu.mx",
        "my.yosemite.edu",
        "mycom.marin.edu",
        "mymail.aacc.edu",
        "mymail.gaston.edu",
        "mymail.tcc.fl.edu",
        "myportal.taftcollege.edu",
        "myunitec.com.mx",
        "mywvm.wvm.edu",
        "mziuri.edu.ge",
        "nbu.edu.cn",
        "nccu.edu.tw",
        "ncepu.cn",
        "ncepu.edu.cn",
        "ncist.edu.cn",
        "ncwu.edu.cn",
        "nenu.edu.cn",
        "nfs.edu.rs",
        "nicu.ac.mu",
        "nihaomeimei.me",
        "ninja",
        "njau.edu.cn",
        "njnu.edu.cn",
        "nju.edu.cn",
        "nkdx.ac.cn",
        "nnu.edu.cn",
        "noc.edu",
        "northfacing.ac.cn",
        "nuc.edu.cn",
        "nwafu.edu.cn",
        "nxmu.edu.cn",
        "occc.edu",
        "otp39.ru",
        "ouc.edu.cn",
        "palomar.edu",
        "paofu.us",
        "paulsmiths.edu",
        "peking.pkumail.tech",
        "pekingwebmail.tech",
        "pipeline.sbcc.edu",
        "post.eurasia.edu",
        "pycharm.ac.cn",
        "qhnu.edu.cn",
        "queens.ac.id",
        "qust.edu.cn",
        "rawafed.edu.ps",
        "riohondo.edu",
        "rochester.edu",
        "rocks",
        "rutgers.edu",
        "s.upc.edu.cn",
        "saddleback.edu",
        "sbcc.edu",
        "sbu.ac.ir",
        "scc.stanly.edu",
        "sch.edu.af",
        "school.mss.sc.ug",
        "scnu.edu.cn",
        "scu.edu.cn",
        "scuec.edu.cn",
        "sdju.edu.cn",
        "sdnu.edu.cn",
        "sdu.edu.cn",
        "sdufe.edu.cn",
        "sdust.edu.cn",
        "sdut.edu.cn",
        "secupv.org",
        "sekaschool.ac.th",
        "sekuco.org",
        "sem.tsinghua.edu.cn",
        "seu.edu.cn",
        "seu.edu.mk",
        "sfu.edu.cn",
        "sharif.edu",
        "sharif.ir",
        "sharkia3.moe.edu.eg",
        "shisu.edu.cn",
        "shitac.tech",
        "shmtu.edu.cn",
        "shu.edu.cn",
        "si.edu",
        "sicau.edu.cn",
        "sierracollege.edu",
        "siit.edu.cn",
        "siswa.email",
        "sit.edu.cn",
        "sjtu.edu.cn",
        "smail.hunnu.edu.cn",
        "smail.nju.edu.cn",
        "smail.skawi.me",
        "smc.edu",
        "snnu.edu.cn",
        "sotcstudent.net",
        "southwest.tn.edu",
        "sss.edu.bi",
        "sstu-edu.ru",
        "st.btbu.edu.cn",
        "st.buh.edu.vn",
        "st.sandau.edu.cn",
        "st.usst.edu.cn",
        "std.uestc.edu.cn",
        "stlcc.edu",
        "stmail.tanenbaumchat.org",
        "stu.ahu.edu.cn",
        "stu.ccsu.edu.cn",
        "stu.centralaz.edu",
        "stu.cihanuniversity.org",
        "stu.colegiotorremalmuerta.es",
        "stu.cpu.edu.cn",
        "stu.cqupt.edu.cn",
        "stu.ctcd.edu",
        "stu.cuz.edu.cn",
        "stu.gzucm.edu.cn",
        "stu.haust.edu.cn",
        "stu.haut.edu.cn",
        "stu.hcnu.edu.cn",
        "stu.hit.edu.cn",
        "stu.hnie.edu.cn",
        "stu.hnucm.edu.cn",
        "stu.hubu.edu.cn",
        "stu.jiangnan.edu.cn",
        "stu.just.edu.cn",
        "stu.kust.edu.cn",
        "stu.liiajc.me",
        "stu.mziuri.edu.ge",
        "stu.ncwu.edu.cn",
        "stu.nmu.edu.cn",
        "stu.nun.edu.cn",
        "stu.parkland.edu",
        "stu.peihua.edu.cn",
        "stu.scau.edu.cn",
        "stu.scu.edu.cn",
        "stu.sdnu.edu.cn",
        "stu.shzu.edu.cn",
        "stu.sisu.edu.cn",
        "stu.sqxy.edu.cn",
        "stu.sxit.edu.cn",
        "stu.t.edu.vn",
        "stu.wxic.edu.cn",
        "stu.xhsysu.edu.cn",
        "stu.xpu.edu.cn",
        "stu.zuel.edu.cn",
        "stud.acdt.edu.cn",
        "student.alamo.edu",
        "student.carlalbert.edu",
        "student.cccs.edu",
        "student.citruscollege.edu",
        "student.ciu.edu.tr",
        "student.cmccd.edu",
        "student.cumtb.edu.cn",
        "student.glendale.edu",
        "student.humg.edu.vn",
        "student.ksu.edu.sa",
        "student.laccd.edu",
        "student.msjc.edu",
        "student.mtsac.edu",
        "student.napavalley.edu",
        "student.nocccd.edu",
        "student.ntu.edu.pk",
        "student.oaklandcc.edu",
        "student.ohlone.edu",
        "student.ptithcm.edu.vn",
        "student.rockvalleycollege.edu",
        "student.sbccd.edu",
        "student.scf.edu",
        "student.smc.edu",
        "student.unsw.edu.au",
        "student.wstkt.edu.pl",
        "students.cccti.edu",
        "students.noc.edu",
        "students.rossu.edu",
        "students.smanra.sch.id",
        "students.solano.edu",
        "students.uwc.edu",
        "students.westerntc.edu",
        "studio",
        "stumail.sdut.edu.cn",
        "subr.edu",
        "suda.edu.cn",
        "sufe.edu.cn",
        "sunydutchess.edu",
        "sus.edu",
        "sust.edu",
        "swccd.edu",
        "swpu.edu.cn",
        "swu.edu.cn",
        "sxlg.ac.cn",
        "sz.pku.edu.cn",
        "t.edu.vn",
        "t.odmail.cn",
        "tccd.edu",
        "tech",
        "tijmu.edu.cn",
        "tjdx.ac.cn",
        "tju.edu.cn",
        "tk",
        "tmu.edu.cn",
        "tongji.edu.cn",
        "tp.edu.tw",
        "tri-c.edu",
        "tse.moe.edu.eg",
        "tsinghua.pkumail.tech",
        "twzhhq.online",
        "uiot.ac.ug",
        "ujs.edu.cn",
        "ul.edu.lb",
        "unijos.edu.ng",
        "unimetroangola.com",
        "unisilvaner.info",
        "uno.edu.gr",
        "uotago.ac.nz",
        "usst.edu.cn",
        "ust.hk",
        "ustb.edu.cn",
        "ustc.edu.cn",
        "vanlanguni.vn",
        "vcccd.edu",
        "vccs.edu",
        "vict.edu.ht",
        "vip.henu.edu.cn",
        "vip.hnist.edu.cn",
        "volmail.jalc.edu",
        "wellsfargocomcardholders.com",
        "whu.edu.cn",
        "wru.vn",
        "wstkt.edu.pl",
        "wust.edu.cn",
        "www.90888.cc",
        "wxic.edu.cn",
        "wzu.edu.cn",
        "x.pycharm.ac.cn",
        "xbdx.ac.cn",
        "xidian.edu.cn",
        "xinfu.ac.cn",
        "xingle.me",
        "xiyou.edu.cn",
        "xjdx.ac.cn",
        "xmu.edu.cn",
        "xs.hnit.edu.cn",
        "xupt.edu.cn",
        "xzyz.edu.cn",
        "yangtzeu.edu.cn",
        "yccd.edu",
        "yzpc.edu.cn",
        "zanestate.edu",
        "zcmu.edu.cn",
        "ze-zha.com",
        "zhaoqian.ninja",
        "zictcollege.com",
        "zjgsu.edu.cn",
        "zjnu.edu.cn",
        "zjsru.edu.cn",
        "zju.edu.cn",
        "zknu.edu.cn",
        "zucc.edu.cn",
        "zuel.edu.cn",
        "zut.edu.cn",
    ]
)



import os
from pathlib import Path

import pytest

from pyswot import find_school_names, is_academic
from pyswot.pyswot import _domain_parts, _find_school_names, _is_stoplisted


@pytest.mark.parametrize(
    "expected,email",
    (
        (True, "lreilly@stanford.edu"),
        (True, "LREILLY@STANFORD.EDU"),
        (True, "Lreilly@Stanford.Edu"),
        (True, "lreilly@slac.stanford.edu"),
        (True, "lreilly@strath.ac.uk"),
        (True, "lreilly@soft-eng.strath.ac.uk"),
        (True, "lee@ugr.es"),
        (True, "lee@uottawa.ca"),
        (True, "lee@mother.edu.ru"),
        (True, "lee@ucy.ac.cy"),
        (False, "lee@leerilly.net"),
        (False, "lee@gmail.com"),
        (False, "lee@stanford.edu.com"),
        (False, "lee@strath.ac.uk.com"),
        (True, "stanford.edu"),
        (True, "slac.stanford.edu"),
        (True, "www.stanford.edu"),
        (True, "http://www.stanford.edu"),
        # Not handling this
        # (True, "http://www.stanford.edu:9393"),
        (True, "strath.ac.uk"),
        (True, "soft-eng.strath.ac.uk"),
        (True, "ugr.es"),
        (True, "uottawa.ca"),
        (True, "mother.edu.ru"),
        (True, "ucy.ac.cy"),
        (False, "leerilly.net"),
        (False, "gmail.com"),
        (False, "stanford.edu.com"),
        (False, "strath.ac.uk.com"),
        (False, ""),
        (False, "the"),
        (True, " stanford.edu"),
        (True, "lee@strath.ac.uk "),
        (False, " gmail.com "),
        (True, "lee@stud.uni-corvinus.hu"),
        (True, "lee@harvard.edu"),
        (True, "lee@mail.harvard.edu"),
        (False, "imposter@si.edu"),
        (False, "lee@mdu.edu.rs"),
        # Iran sanctions are lifted
        (True, "lee@acmt.ac.ir"),
        (True, "lee@xmu.edu.my"),
        (True, "lee@uha.fr"),
    ),
)
def test_swot(expected, email):
    assert expected == is_academic(email)


@pytest.mark.parametrize(
    "expected,email", ((True, "alumni.nottingham.ac.uk"), (False, "nottingham.ac.uk"))
)
def test_stoplist(expected, email):
    assert expected == _is_stoplisted(_domain_parts(email))


def test_find_school_names():
    assert "University of Strathclyde" in find_school_names("lreilly@cs.strath.ac.uk")
    assert "uka tarsadia university,bardoli" in find_school_names(
        "lreilly@cs.strath.ac.uk"
    )
    assert ["BRG Fadingerstraße Linz, Austria"] == find_school_names("lrei@fadi.at")
    assert "St. Petersburg State University" in find_school_names("max@spbu.ru ")
    assert len(find_school_names("foo@shop.com")) == 0


def test_non_utf8_source():
    assert find_school_names("myself@cirvianum.cat") == [None]
    assert is_academic("myself@cirvianum.cat")


def test_files_are_utf8(monkeypatch):
    rootdir = Path(__file__).parent.parent / "pyswot" / "swot" / "lib" / "domains"

    non_unicode_files = []

    for subdir, _, files in os.walk(rootdir):
        for file in files:
            rel_file = str(os.path.relpath(os.path.join(subdir, file), rootdir))
            domain_parts = rel_file.split(".txt")[0].split(os.path.sep)
            try:
                _find_school_names(domain_parts)
            except UnicodeDecodeError:
                non_unicode_files.append(rel_file)

    assert non_unicode_files == []



#!/usr/bin/env python
from typing import List

from setuptools import find_packages, setup

with open("README.rst") as readme_file:
    readme = readme_file.read()

with open("HISTORY.rst") as history_file:
    history = history_file.read()

requirements: List[str] = []

setup_requirements: List[str] = []

test_requirements = ["pytest>=3"]

setup(
    author="James Meakin",
    author_email="code@jmsmkn.com",
    python_requires=">=3.6",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    description="Python wrapper for JetBrains/swot.",
    install_requires=requirements,
    license="Apache Software License 2.0",
    long_description=readme + "\n\n" + history,
    include_package_data=True,
    keywords="pyswot",
    name="pyswot",
    packages=find_packages(include=["pyswot", "pyswot.*"]),
    setup_requires=setup_requirements,
    test_suite="tests",
    tests_require=test_requirements,
    url="https://github.com/diagnijmegen/rse-pyswot",
    version="0.2.0",
    zip_safe=False,
)
